@@ -43,9 +43,9 @@ def items(**filters: typing_extensions.Unpack[Item]) -> typing.Iterable[Item]:
                 if item[key] == value:
                     yield item
             elif isinstance(value, str):
-                if item[key] == value:
+                if str(item[key]).lower() == value.lower():
                     yield item
-                if re.search(value, str(item[key])):
+                if re.search(value, str(item[key]), flags=re.IGNORECASE):
                     yield item
             else:
                 raise TypeError("Bad argument type")
